==> haskell-lsp0-types-0.24.0.0-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp0-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 haskell-lsp-types
version:              0.24.0.0
visibility:           public
id:                   haskell-lsp-types-0.24.0.0-2mGRLv1T5wjLmdWQazgus1
key:                  haskell-lsp-types-0.24.0.0-2mGRLv1T5wjLmdWQazgus1
license:              MIT
copyright:            Alan Zimmerman, 2016-2020
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/alanz/haskell-lsp
synopsis:
    Haskell library for the Microsoft Language Server Protocol, data types

description:
    An implementation of the types to allow language implementors to
    support the Language Server Protocol for their specific language.

category:             Development
abi:                  771a95ab42d276deb347543250a5ec09
exposed:              True
exposed-modules:
    Language.Haskell.LSP.Types Language.Haskell.LSP.Types.Capabilities
    Language.Haskell.LSP.Types.Constants
    Language.Haskell.LSP.Types.Lens
    Language.Haskell.LSP.Types.MessageFuncs
    Language.Haskell.LSP.Types.Utils

hidden-modules:
    Language.Haskell.LSP.Types.ClientCapabilities
    Language.Haskell.LSP.Types.CodeAction
    Language.Haskell.LSP.Types.Color Language.Haskell.LSP.Types.Command
    Language.Haskell.LSP.Types.Completion
    Language.Haskell.LSP.Types.DataTypesJSON
    Language.Haskell.LSP.Types.Diagnostic
    Language.Haskell.LSP.Types.DocumentFilter
    Language.Haskell.LSP.Types.FoldingRange
    Language.Haskell.LSP.Types.Hover Language.Haskell.LSP.Types.List
    Language.Haskell.LSP.Types.Location
    Language.Haskell.LSP.Types.MarkupContent
    Language.Haskell.LSP.Types.Message
    Language.Haskell.LSP.Types.Progress
    Language.Haskell.LSP.Types.Symbol
    Language.Haskell.LSP.Types.TextDocument
    Language.Haskell.LSP.Types.Uri Language.Haskell.LSP.Types.Window
    Language.Haskell.LSP.Types.WorkspaceEdit
    Language.Haskell.LSP.Types.WorkspaceFolders

import-dirs:          /usr/lib/ghc-9.0.1/site-local/haskell-lsp-types-0.24.0.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/haskell-lsp-types-0.24.0.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/haskell-lsp-types-0.24.0.0

hs-libraries:         HShaskell-lsp-types-0.24.0.0-2mGRLv1T5wjLmdWQazgus1
depends:
    aeson-1.5.6.0-GIQJC9Q2rpHALuS1rMMxmB base-4.15.0.0 binary-0.8.8.0
    bytestring-0.10.12.1 data-default-0.7.1.1-IvZDod4GR1F6QW3rWcNSTn
    deepseq-1.4.5.0 filepath-1.4.2.1
    hashable-1.3.2.0-FeHuXTZofY1HfsvuXYo4tc
    lens-5.0.1-7uwGazddQIh4hNwEzPLRik
    network-uri-2.6.4.1-8XTF82YKl805nektk7V97g
    scientific-0.3.7.0-EPSIjBVSbdO587vpGv1Ekl text-1.2.4.1
    unordered-containers-0.2.14.0-A8FnkciaL1YDWhREYvj1Se

haddock-interfaces:
    /usr/share/doc/haskell-lsp0-types/html/haskell-lsp-types.haddock

haddock-html:         /usr/share/doc/haskell-lsp0-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lsp0-types-0.24.0.0-41-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp0-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 haskell-lsp-types
version:              0.24.0.0
visibility:           public
id:                   haskell-lsp-types-0.24.0.0-FLiaDrUZPBeGWe1gpQ8POL
key:                  haskell-lsp-types-0.24.0.0-FLiaDrUZPBeGWe1gpQ8POL
license:              MIT
copyright:            Alan Zimmerman, 2016-2020
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/alanz/haskell-lsp
synopsis:
    Haskell library for the Microsoft Language Server Protocol, data types

description:
    An implementation of the types to allow language implementors to
    support the Language Server Protocol for their specific language.

category:             Development
abi:                  66873abebdd290fc5dd138304f37bab9
exposed:              True
exposed-modules:
    Language.Haskell.LSP.Types Language.Haskell.LSP.Types.Capabilities
    Language.Haskell.LSP.Types.Constants
    Language.Haskell.LSP.Types.Lens
    Language.Haskell.LSP.Types.MessageFuncs
    Language.Haskell.LSP.Types.Utils

hidden-modules:
    Language.Haskell.LSP.Types.ClientCapabilities
    Language.Haskell.LSP.Types.CodeAction
    Language.Haskell.LSP.Types.Color Language.Haskell.LSP.Types.Command
    Language.Haskell.LSP.Types.Completion
    Language.Haskell.LSP.Types.DataTypesJSON
    Language.Haskell.LSP.Types.Diagnostic
    Language.Haskell.LSP.Types.DocumentFilter
    Language.Haskell.LSP.Types.FoldingRange
    Language.Haskell.LSP.Types.Hover Language.Haskell.LSP.Types.List
    Language.Haskell.LSP.Types.Location
    Language.Haskell.LSP.Types.MarkupContent
    Language.Haskell.LSP.Types.Message
    Language.Haskell.LSP.Types.Progress
    Language.Haskell.LSP.Types.Symbol
    Language.Haskell.LSP.Types.TextDocument
    Language.Haskell.LSP.Types.Uri Language.Haskell.LSP.Types.Window
    Language.Haskell.LSP.Types.WorkspaceEdit
    Language.Haskell.LSP.Types.WorkspaceFolders

import-dirs:          /usr/lib/ghc-9.0.1/site-local/haskell-lsp-types-0.24.0.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/haskell-lsp-types-0.24.0.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/haskell-lsp-types-0.24.0.0

hs-libraries:         HShaskell-lsp-types-0.24.0.0-FLiaDrUZPBeGWe1gpQ8POL
depends:
    aeson-1.5.6.0-EMNFVE8fJ8l4Y3HGKS2Pru base-4.15.0.0 binary-0.8.8.0
    bytestring-0.10.12.1 data-default-0.7.1.1-IvZDod4GR1F6QW3rWcNSTn
    deepseq-1.4.5.0 filepath-1.4.2.1
    hashable-1.3.2.0-2579b4ed8EpGiVuNwiQjKE
    lens-5.0.1-FdpuvmTBMS53qHfLYlRUsS
    network-uri-2.6.4.1-BF1HIHRcf8L4FYFNmmtGI3
    scientific-0.3.7.0-8KIW57Kv1SlJGBiyLmlLzk text-1.2.4.1
    unordered-containers-0.2.14.0-9dFFYFCso8sGtsfFV1YYEC

haddock-interfaces:
    /usr/share/doc/haskell-lsp0-types/html/haskell-lsp-types.haddock

haddock-html:         /usr/share/doc/haskell-lsp0-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
